@@ -1,5 +1,5 @@
 """
-Custom signals definitions that representing the Open edX platform events.
+Standardized signals definitions for events within the architecture subdomain ``learning``.
 
 All signals defined in this module must follow the name and versioning
 conventions specified in docs/decisions/0002-events-naming-and-versioning.rst
@@ -13,6 +13,7 @@ from openedx_events.learning.data import (
     CohortData,
     CourseDiscussionConfigurationData,
     CourseEnrollmentData,
+    PersistentCourseGradeData,
     UserData,
 )
 from openedx_events.tooling import OpenEdxPublicSignal
@@ -136,3 +137,14 @@ COURSE_DISCUSSIONS_CHANGED = OpenEdxPublicSignal(
         "configuration": CourseDiscussionConfigurationData
     }
 )
+
+# .. event_type: org.openedx.learning.course.persistent_grade.summary.v1
+# .. event_name: PERSISTENT_GRADE_SUMMARY_CHANGED
+# .. event_description: emitted when a grade changes in the course
+# .. event_data: PersistentCourseGradeData
+PERSISTENT_GRADE_SUMMARY_CHANGED = OpenEdxPublicSignal(
+    event_type="org.openedx.learning.course.persistent_grade_summary.changed.v1",
+    data={
+        "grade": PersistentCourseGradeData,
+    }
+)
